from setuptools import setup

setup(name='ani_probablity',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['ani_probablity'],
      author='Anirudh singh sanger',
      zip_safe=False)
